==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_MX.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Recipient" : "Destinatario",
    "Too many redirects. Aborting ..." : "Demasiadas redirecciones. Abortando...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El servidor remoto no nos otorgó acceso al calendario (error {%s} HTTP)",
    "Error connecting to remote server" : "Se presentó un error al conectarse al servidor remoto",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Se presentó un error al solicitar el recurso en el servidor remoto. Esto se pudo haber presentado por una diferencia en el certificado",
    "Error requesting resource on remote server" : "Se presentó un error al solicitar el recurso al servidor remoto",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Sala",
    "Unknown" : "Desconocido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "No va a asistir",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Te encuentras en una zona horaria desconocida ({tz}), restableciendo UTC",
    "Please create a calendar first." : "Por favor crea un calendario primero.",
    "New event" : "Nuevo evento",
    "CalDAV address for clients" : "Dirección CalDAV para clientes",
    "Error saving WebCal-calendar" : "Error al guardar el calendaro WebCal",
    "WebDAV address for subscriptions" : "Dirección WebDav para suscripciones",
    "Email has been sent." : "El correo electrónico ha sido enviado. ",
    "There was an issue while sending your email." : "Se presentó un tema al enviar tu correo electrónico. ",
    "group" : "grupo",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Repeating" : "Repitiendo",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativo",
    "Cancelled" : "Cancelado",
    "Please add a title." : "Por favor agrega un título.",
    "Please select a calendar." : "Por favor selecciona un calendario.",
    "The event can not end before it starts." : "El evento no puede terminar antes de que inicie.",
    "Global" : "Global",
    "None" : "Ninguno",
    "Every day" : "Todos los días",
    "Every week" : "Todas las semanas",
    "Every month" : "Todos los meses",
    "Every year" : "Todos los años",
    "never" : "nunca",
    "after" : "después",
    "How about getting started by importing some calendars?" : "¿Qué tal si empiezas importando algunos calendarios?",
    "At time of event" : "A la hora del evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personalizado",
    "Audio" : "Audio",
    "Email" : "Correo electrónico",
    "Pop-up" : "Ventana emergente",
    "sec" : "seg",
    "min" : "min",
    "hours" : "horas",
    "days" : "días",
    "week" : "semana",
    "before" : "antes",
    "start" : "iniciar",
    "end" : "terminar",
    "Editing reminders of unknown type not supported." : "Los recordatorios de tipo desconocido no están soportados. ",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported" : "Importado exitosamente",
    "Partially imported, 1 failure" : "Importado parcialmente, 1 falla",
    "Partially imported, {n} failures" : "Importado parcialmente, {n} fallas",
    "Audio alarm" : "Alarma de audio",
    "{type} {time} before the event starts" : "{type} {time} antes de que el evento inicie",
    "{type} {time} before the event ends" : "{type} {time} antes de que el evento termine",
    "{type} {time} after the event starts" : "{type} {time} después de que el evento inicie",
    "{type} {time} after the event ends" : "{type} {time} después de que el evento termine",
    "{type} at the event's start" : "{type} al inicio del evento",
    "{type} at the event's end" : "{type} al final del evento",
    "{type} at {time}" : "{type} a las {time}",
    "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
    "Please enter a valid WebCal-URL" : "Favor de ingresar una URL WebCal válida",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Se presentó un error severo en el proxy webcal. Por favor contacta al adminsitrador para más información. ",
    "Title of the Event" : "Título del Evento",
    "Starts" : "Comienza",
    "Ends" : "Termina",
    "All day Event" : "Evento de todo el día",
    "Delete" : "Borrar",
    "Cancel" : "Cancelar",
    "More ..." : "Más...",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Close" : "Cerrar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Event status" : "Estatus del evento",
    "Visibility when sharing" : "Visibilidad al compartir",
    "Export" : "Exportar",
    "%s has published the calendar %s" : "%s ha publicado el calendario %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Queremos informarte que %s ha publicado el calendario {boldstart}%s{boldend}.",
    "Click here to access it" : "Da click aquí para acceder",
    "We wanted to inform you that %s has published the calendar %s." : "Queremos informarte que %s ha publicado el calendario %s.",
    "Click on the link below to access it" : "Siga la liga para accederlo",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Today" : "Hoy",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Algunos eventos en este calenario están rotos. Por favor verifica la consola JS para más información. ",
    "Share Calendar" : "Compartir Calendario",
    "Shared" : "Compartido",
    "More" : "Más",
    "Edit" : "Editar",
    "Link" : "Liga",
    "iCal link" : "Liga iCal",
    "Download" : "Descargar",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "can edit" : "puede editar",
    "Share link" : "Compartir liga",
    "Public access" : "Acceso público",
    "Email link to person" : "Enviar correo electrónico a la persona",
    "Send" : "Enviar",
    "New Calendar" : "Nuevo calendario",
    "Name" : "Nombre",
    "New Subscription" : "Nueva suscripción",
    "Go back" : "Regresar",
    "Go forward" : "Adelante",
    "Calendar does not exist" : "El calendario no existe",
    "Maybe you got a wrong link or the calendar was unshared?" : "¿Tal vez tienes una liga equivocada o el calendario dejó de ser compartido?",
    "Edit event" : "Editar evento",
    "Delete Event" : "Borrar evento",
    "Save Event" : "Guardar Evento",
    "Time" : "Hora",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "veces cada",
    "Add" : "Agregar",
    "Email address of attendee" : "Dirección de correo electrónico del asistente",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor agrega tu dirección de correo electrónico en los configuraciones personales para poder agregar asistentes. ",
    "from" : "de",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "La regla de repetición de este evento aún no está soportada. ",
    "Support for advanced rules will be added with subsequent updates." : "El soporte a reglas avanzadas se integrará en actualizaciones posteriores.",
    "Reset repeating rule" : "Restablecer la regla de repetición",
    "Repeat every ..." : "Repitir cada ...",
    "end repeat ..." : "fin de repetición ...",
    "times" : "veces",
    "Import Calendars" : "Importar Calendarios",
    "Import canceled" : "Importación calcelada",
    "Analyzing calendar" : "Analizando calendario",
    "The file contains objects incompatible with the selected calendar" : "El archivo contiene objetos incompatibles con el calendario seleccionado",
    "New calendar" : "Nuevo calendario",
    "File is empty" : "El archivo está vacío",
    "Import scheduled" : "Importar agendados",
    "%s shared the calendar <strong>%s</strong> with you" : "%s compartió el calendario <strong>%s</strong> contigo",
    "Embed" : "Integrar",
    "Iframe to integrate" : "Iframe a integrar",
    "Publish URL" : "Publicar URL",
    "Settings & import" : "Configuraciones & importar",
    "Skip simple event editor" : "Omitir el editor de eventos simple",
    "Show week numbers" : "Mostrar número de semana",
    "Import calendar" : "Importar calendario",
    "No Calendars selected for import" : "No se han seleccionado Caldenarios para importar",
    "Primary CalDAV address" : "Dirección principal de CalDAV",
    "iOS/OS X CalDAV address" : "Dirección CalDAV de iOS/OS X",
    "Subscribe" : "Suscríbete"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.6.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_MX.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Recipient" : "Destinatario",
    "Too many redirects. Aborting ..." : "Demasiadas redirecciones. Abortando...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El servidor remoto no nos otorgó acceso al calendario (error {%s} HTTP)",
    "Error connecting to remote server" : "Se presentó un error al conectarse al servidor remoto",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Se presentó un error al solicitar el recurso en el servidor remoto. Esto se pudo haber presentado por una diferencia en el certificado",
    "Error requesting resource on remote server" : "Se presentó un error al solicitar el recurso al servidor remoto",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Sala",
    "Unknown" : "Desconocido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "No va a asistir",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Te encuentras en una zona horaria desconocida ({tz}), restableciendo UTC",
    "Please create a calendar first." : "Por favor crea un calendario primero.",
    "New event" : "Nuevo evento",
    "CalDAV address for clients" : "Dirección CalDAV para clientes",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Algunos eventos en este calenario están rotos. Por favor verifica la consola JS para más información. ",
    "Share Calendar" : "Compartir Calendario",
    "Shared" : "Compartido",
    "Could not save WebCal-calendar" : "No fue posible guardar el calendario-WebCal",
    "WebDAV address for subscriptions" : "Dirección WebDav para suscripciones",
    "Email sent." : "Correo electrónico enviado.",
    "Could not send your email." : "No fue posible enviar tu correo electrónico.",
    "group" : "grupo",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Repeating" : "Repitiendo",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativo",
    "Cancelled" : "Cancelado",
    "Please add a title." : "Por favor agrega un título.",
    "Please select a calendar." : "Por favor selecciona un calendario.",
    "The event can not end before it starts." : "El evento no puede terminar antes de que inicie.",
    "Global" : "Global",
    "None" : "Ninguno",
    "Every day" : "Todos los días",
    "Every week" : "Todas las semanas",
    "Every month" : "Todos los meses",
    "Every year" : "Todos los años",
    "never" : "nunca",
    "after" : "después",
    "How about getting started by importing some calendars?" : "¿Qué tal si empiezas importando algunos calendarios?",
    "At time of event" : "A la hora del evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personalizado",
    "Audio" : "Audio",
    "Email" : "Correo electrónico",
    "Pop-up" : "Ventana emergente",
    "sec" : "seg",
    "min" : "min",
    "hours" : "horas",
    "days" : "días",
    "week" : "semana",
    "before" : "antes",
    "start" : "iniciar",
    "end" : "terminar",
    "Editing reminders of unknown type not supported." : "Los recordatorios de tipo desconocido no están soportados. ",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported {imported} objects" : "Los objetos {imported} fueron importados exitosamente",
    "Imported {imported} out of {all}, skipped one duplicate" : "{imported} importados de {all}, un duplicado omitido",
    "Imported {imported} out of {all}, one failure" : "{imported} importados de {all}, una falla",
    "Imported {imported} out of {all}, {errors} failures" : "{imported} importados de {all},  {errors} fallas",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "{imported} importados de {all}, {duplicates} duplicados omitidos",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "{imported} importados de {all}, {errors} fallas, {duplicates} duplicados omitidos",
    "Audio alarm {time} before the event starts" : "Alarma auditiva {time} antes de que el evento inicie",
    "Pop-up {time} before the event starts" : "Ventana emergente {time} antes de que el evento inicie",
    "Email {time} before the event starts" : "Correo electrónico {time} antes de que el evento inicie",
    "None {time} before the event starts" : "Nada {time} antes de que el evento inicie",
    "{type} {time} before the event starts" : "{type} {time} antes de que el evento inicie",
    "Audio alarm {time} before the event ends" : "Alarma auditiva {time} antes de que el evento termine",
    "Pop-up {time} before the event ends" : "Ventana emergente {time} antes de que el evento termine",
    "Email {time} before the event ends" : "Correo electrónico {time} antes de que el evento termine",
    "None {time} before the event ends" : "Nada {time} antes de que el evento termine",
    "{type} {time} before the event ends" : "{type} {time} antes de que el evento termine",
    "Audio alarm {time} after the event starts" : "Alarma auditiva {time} después de que el evento inicie",
    "Pop-up {time} after the event starts" : "Ventana emergente {time} después de que el evento inicie",
    "Email {time} after the event starts" : "Correo electrónico {time} después de que inicie el evento",
    "None {time} after the event starts" : "Nada {time} después de que inicie el evento",
    "{type} {time} after the event starts" : "{type} {time} después de que el evento inicie",
    "Audio alarm {time} after the event ends" : "Alarma auditiva {time} después de que termine el evento",
    "Pop-up {time} after the event ends" : "Ventana emergente {time} después de que termine el evento",
    "Email {time} after the event ends" : "Correo electrónico {time} después de que termine el evento",
    "None {time} after the event ends" : "Nada {time} después de que termine el evento",
    "{type} {time} after the event ends" : "{type} {time} después de que el evento termine",
    "Audio alarm at the event's start" : "Alarma auditiva al iniciar el evento",
    "Pop-up at the event's start" : "Ventana emergente al inciar el evento",
    "Email at the event's start" : "Correo electrónico al iniciar el evento",
    "None at the event's start" : "Nada al iniciar el evento",
    "{type} at the event's start" : "{type} al inicio del evento",
    "Audio alarm at the event's end" : "Alarma auditiva al terminar el evento",
    "Pop-up at the event's end" : "Ventana emergente al terminar el evento",
    "Email at the event's end" : "Correo electrónico al terminar el evento",
    "None at the event's end" : "Nada al terminar el evento",
    "{type} at the event's end" : "{type} al final del evento",
    "Audio alarm at {time}" : "Alarma auditiva a las {time}",
    "Pop-up at {time}" : "Ventana emergente a las {time}",
    "Email at {time}" : "Correo electrónico a las {time}",
    "None at {time}" : "Nada a las {time}",
    "{type} at {time}" : "{type} a las {time}",
    "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
    "Please enter a valid WebCal-URL" : "Favor de ingresar una URL WebCal válida",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Se presentó un error severo en el proxy webcal. Por favor contacta al adminsitrador para más información. ",
    "Title of the Event" : "Título del Evento",
    "Starts" : "Comienza",
    "Ends" : "Termina",
    "All day Event" : "Evento de todo el día",
    "Delete" : "Borrar",
    "Cancel" : "Cancelar",
    "More ..." : "Más...",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Close" : "Cerrar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Event status" : "Estatus del evento",
    "Visibility when sharing" : "Visibilidad al compartir",
    "Export" : "Exportar",
    "%s has published the calendar %s" : "%s ha publicado el calendario %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Queremos informarte que %s ha publicado el calendario {boldstart}%s{boldend}.",
    "Click here to access it" : "Da click aquí para acceder",
    "We wanted to inform you that %s has published the calendar %s." : "Queremos informarte que %s ha publicado el calendario %s.",
    "Click on the link below to access it" : "Siga la liga para accederlo",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Today" : "Hoy",
    "More" : "Más",
    "Edit" : "Editar",
    "Link" : "Liga",
    "iCal link" : "Liga iCal",
    "Download" : "Descargar",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "can edit" : "puede editar",
    "Share link" : "Compartir liga",
    "Public access" : "Acceso público",
    "Email link to person" : "Enviar correo electrónico a la persona",
    "Send" : "Enviar",
    "New Calendar" : "Nuevo calendario",
    "Name" : "Nombre",
    "New Subscription" : "Nueva suscripción",
    "Go back" : "Regresar",
    "Go forward" : "Adelante",
    "Calendar does not exist" : "El calendario no existe",
    "Maybe you got a wrong link or the calendar was unshared?" : "¿Tal vez tienes una liga equivocada o el calendario dejó de ser compartido?",
    "Edit event" : "Editar evento",
    "Delete Event" : "Borrar evento",
    "Save Event" : "Guardar Evento",
    "Time" : "Hora",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "veces cada",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Los recordatorios por correo electrónico aún no han sido implementados en el servidor CalDAV, así que no serán enviados. ",
    "Add" : "Agregar",
    "Email address of attendee" : "Dirección de correo electrónico del asistente",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor agrega tu dirección de correo electrónico en los configuraciones personales para poder agregar asistentes. ",
    "from" : "de",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "La regla de repetición de este evento aún no está soportada. ",
    "Support for advanced rules will be added with subsequent updates." : "El soporte a reglas avanzadas se integrará en actualizaciones posteriores.",
    "Reset repeating rule" : "Restablecer la regla de repetición",
    "Repeat every ..." : "Repitir cada ...",
    "end repeat ..." : "fin de repetición ...",
    "times" : "veces",
    "Import Calendars" : "Importar Calendarios",
    "Import canceled" : "Importación calcelada",
    "Analyzing calendar" : "Analizando calendario",
    "The file contains objects incompatible with the selected calendar" : "El archivo contiene objetos incompatibles con el calendario seleccionado",
    "New calendar" : "Nuevo calendario",
    "File is empty" : "El archivo está vacío",
    "Import scheduled" : "Importar agendados",
    "%s shared the calendar <strong>%s</strong> with you" : "%s compartió el calendario <strong>%s</strong> contigo",
    "Embed" : "Integrar",
    "Iframe to integrate" : "Iframe a integrar",
    "Publish URL" : "Publicar URL",
    "Settings & import" : "Configuraciones & importar",
    "Import calendar" : "Importar calendario",
    "No Calendars selected for import" : "No se han seleccionado Caldenarios para importar",
    "Skip simple event editor" : "Omitir el editor de eventos simple",
    "Show week numbers" : "Mostrar número de semana",
    "Primary CalDAV address" : "Dirección principal de CalDAV",
    "iOS/OS X CalDAV address" : "Dirección CalDAV de iOS/OS X",
    "Subscribe" : "Suscríbete"
},
"nplurals=2; plural=(n != 1);");
